@@ -30,7 +30,7 @@ local tonumber = tonumber
 return function (apisix_home, pkg_cpath_org, pkg_path_org)
     -- ulimit setting should be checked when APISIX starts
     local res, err = util.execute_cmd("ulimit -n")
-    if not res or err ~= nil then
+    if not res then
         error("failed to exec ulimit cmd \'ulimit -n \', err: " .. err)
     end
     local ulimit = tonumber(util.trim(res))
@@ -72,20 +72,13 @@ return function (apisix_home, pkg_cpath_org, pkg_path_org)
             if ok and json then
                 stderr:write("please remove the cjson library in Lua, it may "
                             .. "conflict with the cjson library in openresty. "
-                            .. "\n luarocks remove cjson\n")
+                            .. "\n luarocks remove lua-cjson\n")
                 exit(1)
             end
         end
     end
 
-    -- pre-transform openresty path
-    res, err = util.execute_cmd("command -v openresty")
-    if not res then
-        error("failed to exec ulimit cmd \'command -v openresty\', err: " .. err)
-    end
-    local openresty_path_abs = util.trim(res)
-
-    local openresty_args = openresty_path_abs .. [[ -p ]] .. apisix_home .. [[ -c ]]
+    local openresty_args = [[openresty -p ]] .. apisix_home .. [[ -c ]]
                            .. apisix_home .. [[/conf/nginx.conf]]
 
     local min_etcd_version = "3.4.0"
